@@ -10,16 +10,16 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 """ This exports methods available for use by plugins for sos """
 
 from __future__ import with_statement
 
 from sos.utilities import (sos_get_command_output, import_module, grep,
-                           fileobj, tail)
+                           fileobj, tail, is_executable)
 import os
 import glob
 import re
@@ -36,6 +36,11 @@ from six.moves import zip, filter
 
 def _to_u(s):
     if not isinstance(s, six.text_type):
+        # Workaround python.six mishandling of strings ending in '\' by
+        # adding a single space following any '\' at end-of-line.
+        # See Six issue #60.
+        if s.endswith('\\'):
+            s += " "
         s = six.u(s)
     return s
 
@@ -76,6 +81,16 @@ def _node_type(st):
             return t[1]
 
 
+def _file_is_compressed(path):
+    """Check if a file appears to be compressed
+
+    Return True if the file specified by path appears to be compressed,
+    or False otherwise by testing the file name extension against a
+    list of known file compression extentions.
+    """
+    return path.endswith(('.gz', '.xz', '.bz', '.bz2'))
+
+
 class Plugin(object):
     """ This is the base class for sosreport plugins. Plugins should subclass
     this and set the class variables where applicable.
@@ -106,6 +121,7 @@ class Plugin(object):
     version = 'unversioned'
     packages = ()
     files = ()
+    commands = ()
     archive = None
     profiles = ()
     sysroot = '/'
@@ -137,13 +153,13 @@ class Plugin(object):
                                    'enabled': opt[3]})
 
     @classmethod
-    def name(class_):
+    def name(cls):
         """Returns the plugin's name as a string. This should return a
         lowercase string.
         """
-        if class_.plugin_name:
-            return class_.plugin_name
-        return class_.__name__.lower()
+        if cls.plugin_name:
+            return cls.plugin_name
+        return cls.__name__.lower()
 
     def _format_msg(self, msg):
         return "[plugin:%s] %s" % (self.name(), msg)
@@ -505,70 +521,81 @@ class Plugin(object):
     def _add_copy_paths(self, copy_paths):
         self.copy_paths.update(copy_paths)
 
-    def add_copy_spec_limit(self, copyspec, sizelimit=None, tailit=True):
+    def add_copy_spec(self, copyspecs, sizelimit=None, tailit=True):
         """Add a file or glob but limit it to sizelimit megabytes. If fname is
         a single file the file will be tailed to meet sizelimit. If the first
         file in a glob is too large it will be tailed to meet the sizelimit.
         """
-        if not (copyspec and len(copyspec)):
+
+        if self.get_option('all_logs'):
+            sizelimit = None
+
+        if sizelimit:
+            sizelimit *= 1024 * 1024  # in MB
+
+        if not copyspecs:
             return False
 
-        if self.use_sysroot():
-            copyspec = self.join_sysroot(copyspec)
-        files = glob.glob(copyspec)
-        files.sort()
-        if len(files) == 0:
-            return
-
-        current_size = 0
-        limit_reached = False
-        sizelimit *= 1024 * 1024  # in MB
-        _file = None
-
-        for _file in files:
-            current_size += os.stat(_file)[stat.ST_SIZE]
-            if sizelimit and current_size > sizelimit:
-                limit_reached = True
-                break
-            self._add_copy_paths([_file])
-
-        if limit_reached and tailit:
-            file_name = _file
-
-            if file_name[0] == os.sep:
-                file_name = file_name.lstrip(os.sep)
-            strfile = file_name.replace(os.path.sep, ".") + ".tailed"
-            self.add_string_as_file(tail(_file, sizelimit), strfile)
-            rel_path = os.path.relpath('/', os.path.dirname(_file))
-            link_path = os.path.join(rel_path, 'sos_strings',
-                                     self.name(), strfile)
-            self.archive.add_link(link_path, _file)
-
-    def add_copy_spec(self, copyspecs):
-        """Add a file specification (can be file, dir,or shell glob) to be
-        copied into the sosreport by this module.
-        """
         if isinstance(copyspecs, six.string_types):
             copyspecs = [copyspecs]
+
         for copyspec in copyspecs:
+            if not (copyspec and len(copyspec)):
+                return False
+
             if self.use_sysroot():
                 copyspec = self.join_sysroot(copyspec)
-            if not (copyspec and len(copyspec)):
-                self._log_warn("added null or empty copy spec")
-                return False
-            copy_paths = self._expand_copy_spec(copyspec)
-            self._add_copy_paths(copy_paths)
-            self._log_info("added copyspec '%s'" % copy_paths)
+
+            files = self._expand_copy_spec(copyspec)
+
+            if len(files) == 0:
+                continue
+
+            # Files hould be sorted in most-recently-modified order, so that
+            # we collect the newest data first before reaching the limit.
+            def getmtime(path):
+                try:
+                    return os.path.getmtime(path)
+                except (OSError, FileNotFoundError):
+                    return 0
+
+            files.sort(key=getmtime, reverse=True)
+            current_size = 0
+            limit_reached = False
+            _file = None
+
+            for _file in files:
+                try:
+                    current_size += os.stat(_file)[stat.ST_SIZE]
+                except (OSError, FileNotFoundError):
+                    self._log_info("failed to stat '%s'" % _file)
+                if sizelimit and current_size > sizelimit:
+                    limit_reached = True
+                    break
+                self._add_copy_paths([_file])
+
+            if limit_reached and tailit and not _file_is_compressed(_file):
+                file_name = _file
+
+                if file_name[0] == os.sep:
+                    file_name = file_name.lstrip(os.sep)
+                strfile = file_name.replace(os.path.sep, ".") + ".tailed"
+                self.add_string_as_file(tail(_file, sizelimit), strfile)
+                rel_path = os.path.relpath('/', os.path.dirname(_file))
+                link_path = os.path.join(rel_path, 'sos_strings',
+                                         self.name(), strfile)
+                self.archive.add_link(link_path, _file)
 
     def get_command_output(self, prog, timeout=300, stderr=True,
-                           chroot=True, runat=None):
+                           chroot=True, runat=None, env=None):
         if chroot or self.commons['cmdlineopts'].chroot == 'always':
             root = self.sysroot
         else:
             root = None
 
         result = sos_get_command_output(prog, timeout=timeout, stderr=stderr,
-                                        chroot=root, chdir=runat)
+                                        chroot=root, chdir=runat,
+                                        env=env)
 
         if result['status'] == 124:
             self._log_warn("command '%s' timed out after %ds"
@@ -577,12 +604,14 @@ class Plugin(object):
         # command not found or not runnable
         if result['status'] == 126 or result['status'] == 127:
             # automatically retry chroot'ed commands in the host namespace
-            if chroot and self.commons['cmdlineopts'].chroot != 'always':
-                self._log_info("command '%s' not found in %s - "
-                               "re-trying in host root"
-                               % (prog.split()[0], root))
-                return self.get_command_output(prog, timeout=timeout,
-                                               chroot=False, runat=runat)
+            if root and root != '/':
+                if self.commons['cmdlineopts'].chroot != 'always':
+                    self._log_info("command '%s' not found in %s - "
+                                   "re-trying in host root"
+                                   % (prog.split()[0], root))
+                    return self.get_command_output(prog, timeout=timeout,
+                                                   chroot=False, runat=runat,
+                                                   env=env)
             self._log_debug("could not run '%s': command not found" % prog)
         return result
 
@@ -603,14 +632,14 @@ class Plugin(object):
 
     def _add_cmd_output(self, cmd, suggest_filename=None,
                         root_symlink=None, timeout=300, stderr=True,
-                        chroot=True, runat=None):
+                        chroot=True, runat=None, env=None):
         """Internal helper to add a single command to the collection list."""
         cmdt = (
             cmd, suggest_filename,
             root_symlink, timeout, stderr,
-            chroot, runat
+            chroot, runat, env
         )
-        _tuplefmt = "('%s', '%s', '%s', %s, '%s', '%s', '%s')"
+        _tuplefmt = "('%s', '%s', '%s', %s, '%s', '%s', '%s', '%s')"
         _logstr = "packed command tuple: " + _tuplefmt
         self._log_debug(_logstr % cmdt)
         self.collect_cmds.append(cmdt)
@@ -618,7 +647,7 @@ class Plugin(object):
 
     def add_cmd_output(self, cmds, suggest_filename=None,
                        root_symlink=None, timeout=300, stderr=True,
-                       chroot=True, runat=None):
+                       chroot=True, runat=None, env=None):
         """Run a program or a list of programs and collect the output"""
         if isinstance(cmds, six.string_types):
             cmds = [cmds]
@@ -627,7 +656,7 @@ class Plugin(object):
         for cmd in cmds:
             self._add_cmd_output(cmd, suggest_filename,
                                  root_symlink, timeout, stderr,
-                                 chroot, runat)
+                                 chroot, runat, env)
 
     def get_cmd_output_path(self, name=None, make=True):
         """Return a path into which this module should store collected
@@ -674,21 +703,23 @@ class Plugin(object):
     def add_string_as_file(self, content, filename):
         """Add a string to the archive as a file named `filename`"""
         self.copy_strings.append((content, filename))
-        content = "..." + (content.splitlines()[0]).decode('utf8', 'ignore')
+        if isinstance(content, six.string_types):
+            content = "..." + content.splitlines()[0]
+        else:
+            content = ("..." +
+                       (content.splitlines()[0]).decode('utf8', 'ignore'))
         self._log_debug("added string '%s' as '%s'" % (content, filename))
 
     def get_cmd_output_now(self, exe, suggest_filename=None,
                            root_symlink=False, timeout=300, stderr=True,
-                           chroot=True, runat=None):
+                           chroot=True, runat=None, env=None):
         """Execute a command and save the output to a file for inclusion in the
         report.
         """
         start = time()
         result = self.get_command_output(exe, timeout=timeout, stderr=stderr,
-                                         chroot=chroot, runat=runat)
-        # 126 means 'found but not executable'
-        if result['status'] == 126 or result['status'] == 127:
-            return None
+                                         chroot=chroot, runat=runat,
+                                         env=env)
         self._log_debug("collected output of '%s' in %s"
                         % (exe.split()[0], time() - start))
 
@@ -807,20 +838,26 @@ class Plugin(object):
                 suggest_filename, root_symlink,
                 timeout,
                 stderr,
-                chroot, runat
+                chroot, runat,
+                env
             ) = progs[0]
             self._log_debug("unpacked command tuple: " +
-                            "('%s', '%s', '%s', %s, '%s', '%s', '%s')" %
+                            "('%s', '%s', '%s', %s, '%s', '%s', '%s', '%s')" %
                             progs[0])
             self._log_info("collecting output of '%s'" % prog)
             self.get_cmd_output_now(prog, suggest_filename=suggest_filename,
                                     root_symlink=root_symlink, timeout=timeout,
-                                    stderr=stderr, chroot=chroot, runat=runat)
+                                    stderr=stderr, chroot=chroot, runat=runat,
+                                    env=env)
 
     def _collect_strings(self):
         for string, file_name in self.copy_strings:
             content = "..."
-            content += (string.splitlines()[0]).decode('utf8', 'ignore')
+            if isinstance(string, six.string_types):
+                content = "..." + content.splitlines()[0]
+            else:
+                content = ("..." +
+                           (content.splitlines()[0]).decode('utf8', 'ignore'))
             self._log_info("collecting string '%s' as '%s'"
                            % (content, file_name))
             try:
@@ -852,25 +889,60 @@ class Plugin(object):
 
     def check_enabled(self):
         """This method will be used to verify that a plugin should execute
-        given the condition of the underlying environment. The default
-        implementation will return True if neither class.files or
-        class.packages is specified. If either are specified the plugin will
-        check for the existence of any of the supplied files or packages and
-        return True if any exist. It is encouraged to override this method if
-        this behavior isn't applicable.
+        given the condition of the underlying environment.
+
+        The default implementation will return True if none of class.files,
+        class.packages, nor class.commands is specified. If any of these is
+        specified the plugin will check for the existence of any of the
+        corresponding paths, packages or commands and return True if any
+        are present.
+
+        For SCLPlugin subclasses, it will check whether the plugin can be run
+        for any of installed SCLs. If so, it will store names of these SCLs
+        on the plugin class in addition to returning True.
+
+        For plugins with more complex enablement checks this method may be
+        overridden.
         """
         # some files or packages have been specified for this package
-        if self.files or self.packages:
+        if any([self.files, self.packages, self.commands]):
             if isinstance(self.files, six.string_types):
                 self.files = [self.files]
 
             if isinstance(self.packages, six.string_types):
                 self.packages = [self.packages]
 
-            return (any(os.path.exists(fname) for fname in self.files) or
-                    any(self.is_installed(pkg) for pkg in self.packages))
+            if isinstance(self.commands, six.string_types):
+                self.commands = [self.commands]
+
+            if isinstance(self, SCLPlugin):
+                # save SCLs that match files or packages
+                type(self)._scls_matched = []
+                for scl in self._get_scls():
+                    files = [f % {"scl_name": scl} for f in self.files]
+                    packages = [p % {"scl_name": scl} for p in self.packages]
+                    commands = [c % {"scl_name": scl} for c in self.commands]
+                    if self._files_pkgs_or_cmds_present(files,
+                                                        packages,
+                                                        commands):
+                        type(self)._scls_matched.append(scl)
+                return len(type(self)._scls_matched) > 0
+
+            return self._files_pkgs_or_cmds_present(self.files,
+                                                    self.packages,
+                                                    self.commands)
+
+        if isinstance(self, SCLPlugin):
+            # if files and packages weren't specified, we take all SCLs
+            type(self)._scls_matched = self._get_scls()
+
         return True
 
+    def _files_pkgs_or_cmds_present(self, files, packages, commands):
+            return (any(os.path.exists(fname) for fname in files) or
+                    any(self.is_installed(pkg) for pkg in packages) or
+                    any(is_executable(cmd) for cmd in commands))
+
     def default_enabled(self):
         """This decides whether a plugin should be automatically loaded or
         only if manually specified in the command line."""
@@ -883,6 +955,19 @@ class Plugin(object):
         """
         self.add_copy_spec(list(self.files))
 
+    def setup_verify(self):
+        if not hasattr(self, "verify_packages") or not self.verify_packages:
+            if hasattr(self, "packages") and self.packages:
+                # Limit automatic verification to only the named packages
+                self.verify_packages = [p + "$" for p in self.packages]
+            else:
+                return
+
+        pm = self.policy().package_manager
+        verify_cmd = pm.build_verify_command(self.verify_packages)
+        if verify_cmd:
+            self.add_cmd_output(verify_cmd)
+
     def postproc(self):
         """Perform any postprocessing. To be replaced by a plugin if required.
         """
@@ -947,6 +1032,82 @@ class RedHatPlugin(object):
     pass
 
 
+class SCLPlugin(RedHatPlugin):
+    """Superclass for plugins operating on Software Collections (SCLs).
+
+    Subclasses of this plugin class can specify class.files and class.packages
+    using "%(scl_name)s" interpolation. The plugin invoking mechanism will try
+    to match these against all found SCLs on the system. SCLs that do match
+    class.files or class.packages are then accessible via self.scls_matched
+    when the plugin is invoked.
+
+    Additionally, this plugin class provides "add_cmd_output_scl" (run
+    a command in context of given SCL), and "add_copy_spec_scl" and
+    "add_copy_spec_limit_scl" (copy package from file system of given SCL).
+
+    For example, you can implement a plugin that will list all global npm
+    packages in every SCL that contains "npm" package:
+
+    class SCLNpmPlugin(Plugin, SCLPlugin):
+        packages = ("%(scl_name)s-npm",)
+
+        def setup(self):
+            for scl in self.scls_matched:
+                self.add_cmd_output_scl(scl, "npm ls -g --json")
+    """
+
+    @property
+    def scls_matched(self):
+        if not hasattr(type(self), '_scls_matched'):
+            type(self)._scls_matched = []
+        return type(self)._scls_matched
+
+    def _get_scls(self):
+        output = sos_get_command_output("scl -l")["output"]
+        return [scl.strip() for scl in output.splitlines()]
+
+    def add_cmd_output_scl(self, scl, cmds, **kwargs):
+        """Same as add_cmd_output, except that it wraps command in
+        "scl enable" call.
+        """
+        if isinstance(cmds, six.string_types):
+            cmds = [cmds]
+        scl_cmds = []
+        scl_cmd_tpl = "scl enable %s \"%s\""
+        for cmd in cmds:
+            scl_cmds.append(scl_cmd_tpl % (scl, cmd))
+        self.add_cmd_output(scl_cmds, **kwargs)
+
+    # config files for Software Collections are under /etc/opt/rh/${scl} and
+    # var files are under /var/opt/rh/${scl}. So we need to insert the paths
+    # after the appropriate root dir.
+    def convert_copyspec_scl(self, scl, copyspec):
+        for rootdir in ['etc', 'var']:
+            p = re.compile('^/%s/' % rootdir)
+            copyspec = p.sub('/%s/opt/rh/%s/' % (rootdir, scl), copyspec)
+        return copyspec
+
+    def add_copy_spec_scl(self, scl, copyspecs):
+        """Same as add_copy_spec, except that it prepends path to SCL root
+        to "copyspecs".
+        """
+        if isinstance(copyspecs, six.string_types):
+            copyspecs = [copyspecs]
+        scl_copyspecs = []
+        for copyspec in copyspecs:
+            scl_copyspecs.append(self.convert_copyspec_scl(scl, copyspec))
+        self.add_copy_spec(scl_copyspecs)
+
+    def add_copy_spec_limit_scl(self, scl, copyspec, **kwargs):
+        """Same as add_copy_spec_limit, except that it prepends path to SCL
+        root to "copyspec".
+        """
+        self.add_copy_spec_limit(
+            self.convert_copyspec_scl(scl, copyspec),
+            **kwargs
+        )
+
+
 class PowerKVMPlugin(RedHatPlugin):
     """Tagging class for IBM PowerKVM Linux"""
     pass
