@@ -8,9 +8,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 
@@ -19,6 +19,7 @@ class Acpid(Plugin):
     """ACPI daemon information"""
     plugin_name = "acpid"
     profiles = ('hardware',)
+    packages = ('acpid',)
 
 
 class RedHatAcpid(Acpid, RedHatPlugin):
@@ -33,4 +34,4 @@ class DebianAcpid(Acpid, DebianPlugin, UbuntuPlugin):
         self.add_copy_spec([
             "/etc/acpi/events/powerbtn*"])
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
