@@ -1,4 +1,5 @@
 # Copyright (C) 2014 Red Hat, Inc., Bryn M. Reeves <bmr@redhat.com>
+
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -9,24 +10,49 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 
 
-class ActiveMq(Plugin, RedHatPlugin, DebianPlugin):
+class ActiveMq(Plugin, DebianPlugin):
     """ActiveMQ message broker
     """
 
     plugin_name = 'activemq'
-    profiles = ()
+    profiles = ('openshift',)
     packages = ('activemq', 'activemq-core')
     files = ('/var/log/activemq',)
 
     def setup(self):
-        self.add_copy_spec(list(self.files))
+        if self.get_option("all_logs"):
+            self.add_copy_spec(list(self.files))
+        else:
+            self.add_copy_spec([
+                "/var/log/activemq/activemq.log",
+                "/var/log/activemq/wrapper.log"
+            ])
+
+    def postproc(self):
+        # activemq.xml contains credentials in this form:
+        #   <authenticationUser ... password="changeme" ... />
+        self.do_file_sub(
+            '/etc/activemq/activemq.xml',
+            r'(\s*password=")[^"]*(".*)',
+            r"\1******\2"
+        )
+
+
+class RedHatActiveMq(ActiveMq, RedHatPlugin):
+
+    def setup(self):
+        super(RedHatActiveMq, self).setup()
+        self.add_copy_spec([
+            '/etc/sysconfig/activemq',
+            '/etc/activemq/activemq.xml'
+        ])
 
 
 class UbuntuActiveMq(ActiveMq, UbuntuPlugin):
