@@ -8,9 +8,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin
 import os
@@ -22,6 +22,7 @@ class Anaconda(Plugin, RedHatPlugin):
 
     plugin_name = 'anaconda'
     profiles = ('system',)
+    packages = ('anaconda',)
 
     files = (
         '/var/log/anaconda.log',
@@ -39,7 +40,7 @@ class Anaconda(Plugin, RedHatPlugin):
             paths.append('/var/log/anaconda')
         else:
             paths = paths + [
-                "/var/log/anaconda.*"
+                "/var/log/anaconda.*",
                 "/root/install.log",
                 "/root/install.log.syslog"
             ]
@@ -54,8 +55,8 @@ class Anaconda(Plugin, RedHatPlugin):
         )
         self.do_file_sub(
             "/root/anaconda-ks.cfg",
-            r"(user.*--password=*)(\S*)",
+            r"(user.*--password=*\s*)\s*(\S*)",
             r"\1********"
         )
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
