@@ -8,9 +8,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 
@@ -29,13 +29,15 @@ class Auditd(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
             "/etc/audit/auditd.conf",
             "/etc/audit/audit.rules"
         ])
-        self.add_cmd_output("ausearch --input-logs -m avc,user_avc -ts today")
+        self.add_cmd_output([
+            "ausearch --input-logs -m avc,user_avc -ts today",
+            "auditctl -s"
+        ])
 
         if not self.get_option("all_logs"):
             limit = self.get_option("log_size")
-            self.add_copy_spec_limit("/var/log/audit/audit.log",
-                                     sizelimit=limit)
+            self.add_copy_spec("/var/log/audit/audit.log", sizelimit=limit)
         else:
             self.add_copy_spec("/var/log/audit")
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
