@@ -8,9 +8,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 
@@ -28,6 +28,9 @@ class Cgroups(Plugin, DebianPlugin, UbuntuPlugin):
             "/proc/cgroups",
             "/sys/fs/cgroup"
         ])
+
+        self.add_cmd_output("systemd-cgls")
+
         return
 
 
@@ -43,4 +46,4 @@ class RedHatCgroups(Cgroups, RedHatPlugin):
             "/etc/cgrules.conf"
         ])
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
