@@ -12,9 +12,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin
 from os.path import exists
@@ -25,13 +25,16 @@ class CertificateSystem(Plugin, RedHatPlugin):
     """Certificate System and Dogtag
     """
 
-    plugin_name = 'certificatesystem'
+    plugin_name = 'cs'
     profiles = ('identity', 'security')
 
     packages = (
         "redhat-cs",
         "rhpki-common",
-        "pki-common"
+        "pki-common",
+        "redhat-pki",
+        "dogtag-pki",
+        "pki-base"
     )
 
     files = (
@@ -47,12 +50,17 @@ class CertificateSystem(Plugin, RedHatPlugin):
                 len(glob("/var/lib/rhpki-*")):
             return 73
         # 8 should cover dogtag
-        elif self.is_installed("pki-common") or exists("/usr/share/java/pki"):
+        elif self.is_installed("pki-common"):
             return 8
+        elif self.is_installed("redhat-pki") or \
+                self.is_installed("dogtag-pki") or \
+                self.is_installed("pki-base"):
+            return 9
         return False
 
     def setup(self):
         csversion = self.checkversion()
+
         if not csversion:
             self.add_alert("Red Hat Certificate System not found.")
             return
@@ -96,5 +104,25 @@ class CertificateSystem(Plugin, RedHatPlugin):
                 "/var/log/pki-*/transactions",
                 "/var/log/pki-*/system"
             ])
+        if csversion == 9:
+            # Get logs and configs for each subsystem if installed
+            for subsystem in ('ca', 'kra', 'ocsp', 'tks', 'tps'):
+                self.add_copy_spec([
+                    "/var/lib/pki/*/" + subsystem + "/conf/CS.cfg",
+                    "/var/lib/pki/*/logs/" + subsystem + "/system",
+                    "/var/lib/pki/*/logs/" + subsystem + "/transactions",
+                    "/var/lib/pki/*/logs/" + subsystem + "/debug",
+                    "/var/lib/pki/*/logs/" + subsystem + "/selftests.log"
+                ])
 
-# vim: et ts=4 sw=4
+            # Common log files
+            self.add_copy_spec([
+                "/var/lib/pki/*/logs/catalina.*",
+                "/var/lib/pki/*/logs/localhost*.log",
+                "/var/lib/pki/*/logs/localhost*.txt",
+                "/var/lib/pki/*/logs/manager*.log",
+                "/var/lib/pki/*/logs/host-manager*.log",
+                "/var/lib/pki/*/logs/tps/tokendb-audit.log"
+            ])
+
+# vim: set et ts=4 sw=4 :
