@@ -10,9 +10,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin
 
@@ -28,6 +28,13 @@ class DistUpgrade(Plugin):
 
 class RedHatDistUpgrade(DistUpgrade, RedHatPlugin):
 
+    packages = (
+        'preupgrade-assistant',
+        'preupgrade-assistant-ui',
+        'preupgrade-assistant-el6toel7',
+        'redhat-upgrade-tool'
+    )
+
     files = (
         "/var/log/upgrade.log",
         "/var/log/redhat_update_tool.log",
@@ -54,4 +61,4 @@ class RedHatDistUpgrade(DistUpgrade, RedHatPlugin):
             r"/home/******** path redacted ********"
         )
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
