@@ -1,4 +1,5 @@
 # Copyright (c) 2012 Adam Stokes <adam.stokes@canonical.com>
+
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -9,9 +10,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, DebianPlugin, UbuntuPlugin
 
@@ -24,7 +25,18 @@ class Dpkg(Plugin, DebianPlugin, UbuntuPlugin):
     profiles = ('sysmgmt', 'packagemanager')
 
     def setup(self):
-        self.add_copy_spec("/var/log/dpkg.log")
         self.add_cmd_output("dpkg -l", root_symlink="installed-debs")
+        if self.get_option("verify"):
+            self.add_cmd_output("dpkg -V")
+            self.add_cmd_output("dpkg -C")
+        self.add_copy_spec([
+            "/var/cache/debconf/config.dat",
+            "/etc/debconf.conf"
+        ])
+        if not self.get_option("all_logs"):
+            limit = self.get_option("log_size")
+            self.add_copy_spec("/var/log/dpkg.log", sizelimit=limit)
+        else:
+            self.add_copy_spec("/var/log/dpkg.log*")
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
