@@ -10,24 +10,26 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin
 
 
 class Foreman(Plugin, RedHatPlugin):
-    """Foreman systems management
+    """Foreman/Satellite 6 systems management
     """
 
     plugin_name = 'foreman'
     profiles = ('sysmgmt',)
-    packages = ('foreman')
+    packages = ('foreman-debug',)
 
     def setup(self):
         cmd = "foreman-debug"
-        path = self.get_cmd_output_path(name="foreman-debug")
-        self.add_cmd_output("%s -q -a -d %s" % (cmd, path))
 
-# vim: et ts=4 sw=4
+        path = self.get_cmd_output_path(name="foreman-debug")
+        self.add_cmd_output("%s -g -q -a -d %s" % (cmd, path),
+                            chroot=self.tmp_in_sysroot(), timeout=900)
+
+# vim: set et ts=4 sw=4 :
