@@ -8,9 +8,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin, UbuntuPlugin, DebianPlugin
 
@@ -20,6 +20,7 @@ class Java(Plugin, RedHatPlugin, UbuntuPlugin, DebianPlugin):
 
     plugin_name = "java"
     profiles = ('webserver', 'java')
+    verify_packages = ('java.*',)
 
     def setup(self):
         self.add_copy_spec("/etc/java")
@@ -29,4 +30,4 @@ class Java(Plugin, RedHatPlugin, UbuntuPlugin, DebianPlugin):
         self.add_cmd_output("readlink -f /usr/bin/java")
 
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
