@@ -29,18 +29,18 @@ class KernelRT(Plugin, RedHatPlugin):
     files = ('/sys/kernel/realtime',)
 
     def setup(self):
+        clocksource_path = '/sys/devices/system/clocksource/clocksource0/'
         self.add_copy_spec([
             '/etc/rtgroups',
             '/proc/sys/kernel/sched_rt_period_us',
             '/proc/sys/kernel/sched_rt_runtime_us',
             '/sys/kernel/realtime',
-            '/sys/devices/system/clocksource/clocksource0/'
-            'available_clocksource',
-            '/sys/devices/system/clocksource/clocksource0/current_clocksource'
+            clocksource_path + 'available_clocksource',
+            clocksource_path + 'current_clocksource'
         ])
         # note: rhbz#1059685 'tuna - NameError: global name 'cgroups' is not
         # defined this command throws an exception on versions prior to
         # 0.10.4-5.
         self.add_cmd_output('tuna -CP')
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
