@@ -1,4 +1,5 @@
 # Copyright (C) 2014 Red Hat, Inc. Bryn M. Reeves <bmr@redhat.com>
+
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -9,9 +10,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin
 import re
@@ -27,6 +28,8 @@ class Kpatch(Plugin, RedHatPlugin):
 
     def setup(self):
         kpatch_list = self.get_cmd_output_now("kpatch list")
+        if not kpatch_list:
+            return
         kpatches = open(kpatch_list, "r").read().splitlines()
         for patch in kpatches:
             if not re.match("^kpatch-.*\(.*\)", patch):
@@ -35,4 +38,4 @@ class Kpatch(Plugin, RedHatPlugin):
             self.add_cmd_output("kpatch info " + module)
 
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
