@@ -8,9 +8,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 
@@ -94,11 +94,11 @@ class DebianLdap(Ldap, DebianPlugin, UbuntuPlugin):
             suggest_filename="access_control_lists")
 
     def postproc(self):
-        super(RedHatLdap, self).postproc()
+        super(DebianLdap, self).postproc()
         self.do_cmd_output_sub(
-            "ldapsearch"
+            "ldapsearch",
             r"(olcRootPW\: \s*)\S+",
             r"\1********"
         )
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
