@@ -4,21 +4,21 @@
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-#
+
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, UbuntuPlugin
 
 
 class Maas(Plugin, UbuntuPlugin):
-    """Ubuntu Metal-as-a-Service
+    """Ubuntu Metal-As-A-Service
     """
 
     plugin_name = 'maas'
@@ -56,15 +56,19 @@ class Maas(Plugin, UbuntuPlugin):
         self.add_cmd_output([
             "apt-cache policy maas-*",
             "apt-cache policy python-django-*",
-            "maas dumpdata"
         ])
 
+        if self.is_installed("maas-region-controller"):
+            self.add_cmd_output([
+                "maas-region-admin dumpdata",
+            ])
+
         if self._has_login_options():
             if self._remote_api_login():
                 self.add_cmd_output("maas %s commissioning-results list" %
                                     self.get_option("profile-name"))
             else:
                 self._log_error(
-                    "Cannot login into Maas remote API with provided creds.")
+                    "Cannot login into MAAS remote API with provided creds.")
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
