@@ -8,9 +8,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 
@@ -27,9 +27,17 @@ class Memory(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
             "/proc/pci",
             "/proc/meminfo",
             "/proc/vmstat",
+            "/proc/swaps",
             "/proc/slabinfo",
-            "/proc/pagetypeinfo"])
+            "/proc/pagetypeinfo",
+            "/proc/vmallocinfo",
+            "/sys/kernel/mm/ksm",
+            "/sys/kernel/mm/transparent_hugepage/enabled"
+        ])
         self.add_cmd_output("free", root_symlink="free")
-        self.add_cmd_output("free -m")
+        self.add_cmd_output([
+            "free -m",
+            "swapon --bytes --show"
+        ])
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
