@@ -10,9 +10,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 
@@ -25,9 +25,17 @@ class OpenVSwitch(Plugin):
 
     def setup(self):
 
+        all_logs = self.get_option("all_logs")
+        limit = self.get_option("log_size")
+
+        if not all_logs:
+            self.add_copy_spec("/var/log/openvswitch/*.log",
+                               sizelimit=limit)
+        else:
+            self.add_copy_spec("/var/log/openvswitch/",
+                               sizelimit=limit)
+
         self.add_copy_spec([
-            "/var/log/openvswitch/ovs-vswitchd.log",
-            "/var/log/openvswitch/ovsdb-server.log",
             "/var/run/openvswitch/ovsdb-server.pid",
             "/var/run/openvswitch/ovs-vswitchd.pid"
         ])
@@ -36,6 +44,8 @@ class OpenVSwitch(Plugin):
             # The '-s' option enables dumping of packet counters on the
             # ports.
             "ovs-dpctl -s show",
+            # Capture the in-kernel flow information if it exists
+            "ovs-dpctl dump-flows -m",
             # The '-t 5' adds an upper bound on how long to wait to connect
             # to the Open vSwitch server, avoiding hangs when running sos.
             "ovs-vsctl -t 5 show",
@@ -45,6 +55,9 @@ class OpenVSwitch(Plugin):
             "ls -laZ /var/run/openvswitch",
             # List devices and their drivers
             "dpdk_nic_bind --status",
+            "dpdk_devbind.py --status",
+            "driverctl list-devices",
+            "driverctl list-overrides",
             # Capture a list of all bond devices
             "ovs-appctl bond/list",
             # Capture more details from bond devices
@@ -62,12 +75,20 @@ class OpenVSwitch(Plugin):
             # Capture upcall information
             "ovs-appctl upcall/show",
             # Capture DPDK and other parameters
-            "ovs-vsctl -t 5 get Open_vSwitch . other_config"
+            "ovs-vsctl -t 5 get Open_vSwitch . other_config",
+            # Capture DPDK datapath packet counters and config
+            "ovs-appctl dpctl/show -s",
+            # Capture DPDK queue to pmd mapping
+            "ovs-appctl dpif-netdev/pmd-rxq-show",
+            # Capture DPDK pmd stats
+            "ovs-appctl dpif-netdev/pmd-stats-show"
         ])
 
         # Gather systemd services logs
         self.add_journal(units="openvswitch")
         self.add_journal(units="openvswitch-nonetwork")
+        self.add_journal(units="ovs-vswitchd")
+        self.add_journal(units="ovsdb-server")
 
         # Gather additional output for each OVS bridge on the host.
         br_list_result = self.call_ext_prog("ovs-vsctl list-br")
@@ -83,6 +104,32 @@ class OpenVSwitch(Plugin):
                     "ovs-ofctl show %s" % br
                 ])
 
+                # Flow protocols currently supported
+                flow_versions = [
+                    "OpenFlow10",
+                    "OpenFlow11",
+                    "OpenFlow12",
+                    "OpenFlow13"
+                ]
+
+                # List protocols currently in use, if any
+                ovs_list_bridge_cmd = "ovs-vsctl list bridge %s" % br
+                br_info_file = self.get_cmd_output_now(ovs_list_bridge_cmd)
+
+                br_info = open(br_info_file).read()
+                for line in br_info.splitlines():
+                    if "protocols" in line:
+                        br_protos_ln = line[line.find("[")+1:line.find("]")]
+                        br_protos = br_protos_ln.replace('"', '').split(", ")
+
+                # Collect flow information for relevant protocol versions only
+                for flow in flow_versions:
+                    if flow in br_protos:
+                        self.add_cmd_output([
+                            "ovs-ofctl -O %s dump-flows %s" % (flow, br),
+                            "ovs-ofctl -O %s dump-ports-desc %s" % (flow, br)
+                        ])
+
 
 class RedHatOpenVSwitch(OpenVSwitch, RedHatPlugin):
 
