@@ -12,9 +12,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 import os
 import re
@@ -83,6 +83,9 @@ class Ovirt(Plugin, RedHatPlugin):
 
         self.add_forbidden_path('/etc/ovirt-engine/.pgpass')
         self.add_forbidden_path('/etc/rhevm/.pgpass')
+        # Copy all engine tunables and domain information
+        self.add_cmd_output("engine-config --all")
+        self.add_cmd_output("engine-manage-domains list")
         # Copy engine config files.
         self.add_copy_spec([
             "/etc/ovirt-engine",
@@ -171,4 +174,31 @@ class Ovirt(Plugin, RedHatPlugin):
                 r'{key}=********'.format(key=key)
             )
 
+        # Answer files contain passwords
+        for key in (
+            'OVESETUP_CONFIG/adminPassword',
+            'OVESETUP_CONFIG/remoteEngineHostRootPassword',
+            'OVESETUP_DWH_DB/password',
+            'OVESETUP_DB/password',
+            'OVESETUP_REPORTS_CONFIG/adminPassword',
+            'OVESETUP_REPORTS_DB/password',
+        ):
+            self.do_path_regex_sub(
+                r'/var/lib/ovirt-engine/setup/answers/.*',
+                r'{key}=(.*)'.format(key=key),
+                r'{key}=********'.format(key=key)
+            )
+
+        # aaa profiles contain passwords
+        protect_keys = [
+            "vars.password",
+            "pool.default.auth.simple.password",
+            "pool.default.ssl.truststore.password",
+            "config.datasource.dbpassword"
+        ]
+        regexp = r"((?m)^\s*#*(%s)\s*=\s*)(.*)" % "|".join(protect_keys)
+
+        self.do_path_regex_sub("/etc/ovirt-engine/aaa/.*\.properties", regexp,
+                               r"\1*********")
+
 # vim: expandtab tabstop=4 shiftwidth=4
