@@ -8,21 +8,23 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 from datetime import datetime, timedelta
 import re
+import os.path
 
 
-class Pacemaker(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
+class Pacemaker(Plugin, DebianPlugin, UbuntuPlugin):
     """HA Cluster resource manager"""
 
     plugin_name = "pacemaker"
     profiles = ("cluster", )
     packages = ["pacemaker"]
+    defaults = "/etc/default/pacemaker"
 
     option_list = [
         ("crm_from", "specify the start time for crm_report", "fast", False),
@@ -32,9 +34,10 @@ class Pacemaker(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
     def setup(self):
         self.add_copy_spec([
             "/var/lib/pacemaker/cib/cib.xml",
-            "/etc/sysconfig/pacemaker",
+            self.defaults,
             "/var/log/pacemaker.log",
-            "/var/log/pcsd/pcsd.log"
+            "/var/log/pcsd/pcsd.log",
+            "/var/log/pacemaker/bundles/*/",
         ])
         self.add_cmd_output([
             "crm_mon -1 -A -n -r -t",
@@ -44,6 +47,7 @@ class Pacemaker(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
             "pcs status",
             "pcs property list --all"
         ])
+
         # crm_report needs to be given a --from "YYYY-MM-DD HH:MM:SS" start
         # time in order to collect data.
         crm_from = (datetime.today() -
@@ -69,6 +73,21 @@ class Pacemaker(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
                             (crm_scrub, crm_dest, crm_from),
                             chroot=self.tmp_in_sysroot())
 
+        # collect user-defined logfiles, matching pattern:
+        # PCMK_loggfile=filename
+        # specified in the pacemaker defaults file.
+        pattern = '^\s*PCMK_logfile=[\'\"]?(\S+)[\'\"]?\s*(\s#.*)?$'
+        if os.path.isfile(self.defaults):
+            with open(self.defaults) as f:
+                for line in f:
+                    if re.match(pattern, line):
+                        # remove trailing and leading quote marks, in case the
+                        # line is e.g. PCMK_logfile="/var/log/pacemaker.log"
+                        logfile = re.search(pattern, line).group(1)
+                        for regexp in [r'^"', r'"$', r'^\'', r'\'$']:
+                            logfile = re.sub(regexp, '', logfile)
+                        self.add_copy_spec(logfile)
+
     def postproc(self):
         self.do_cmd_output_sub(
             "pcs config",
@@ -76,4 +95,13 @@ class Pacemaker(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
             r"\1********"
         )
 
+
+class RedHatPacemaker(Pacemaker, RedHatPlugin):
+    """ Handle alternate location of pacemaker defaults file.
+    """
+    def setup(self):
+        self.defaults = "/etc/sysconfig/pacemaker"
+        super(RedHatPacemaker, self).setup()
+
+
 # vim: et ts=4 sw=4
