@@ -8,9 +8,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 # This plugin enables collection of logs for Power systems and more
 # specific logs for Pseries, PowerNV platforms.
@@ -27,7 +27,7 @@ class PowerPC(Plugin, RedHatPlugin, UbuntuPlugin, DebianPlugin):
     profiles = ('system', 'hardware')
 
     def check_enabled(self):
-        return (self.policy().get_arch() == "ppc64")
+        return "ppc64" in self.policy().get_arch()
 
     def setup(self):
         try:
@@ -57,9 +57,7 @@ class PowerPC(Plugin, RedHatPlugin, UbuntuPlugin, DebianPlugin):
                 "ppc64_cpu --run-mode",
                 "ppc64_cpu --frequency",
                 "ppc64_cpu --dscr",
-                "lscfg -vp",
-                "lsmcode -A",
-                "lsvpd --debug"
+                "diag_encl -v"
             ])
 
         if ispSeries:
@@ -70,7 +68,6 @@ class PowerPC(Plugin, RedHatPlugin, UbuntuPlugin, DebianPlugin):
                 "/var/log/platform"
             ])
             self.add_cmd_output([
-                "lsvio -des",
                 "servicelog --dump",
                 "servicelog_notify --list",
                 "usysattn",
@@ -83,8 +80,8 @@ class PowerPC(Plugin, RedHatPlugin, UbuntuPlugin, DebianPlugin):
         if isPowerNV:
             self.add_copy_spec([
                 "/proc/ppc64/eeh",
-                "/proc/ppc64/systemcfg"
-                "/proc/ppc64/topology_updates"
+                "/proc/ppc64/systemcfg",
+                "/proc/ppc64/topology_updates",
                 "/sys/firmware/opal/msglog",
                 "/var/log/opal-elog/"
             ])
@@ -92,4 +89,4 @@ class PowerPC(Plugin, RedHatPlugin, UbuntuPlugin, DebianPlugin):
                 self.add_cmd_output("ls -l /var/log/dump")
 
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
