@@ -8,9 +8,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 
@@ -23,16 +23,29 @@ class Samba(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
     profiles = ('services',)
 
     def setup(self):
+        self.limit = self.get_option("log_size")
+
         self.add_copy_spec([
             "/etc/samba/smb.conf",
             "/etc/samba/lmhosts",
-            "/var/log/samba/log.smbd",
-            "/var/log/samba/log.nmbd"
         ])
+
+        self.add_copy_spec("/var/log/samba/log.smbd", sizelimit=self.limit)
+        self.add_copy_spec("/var/log/samba/log.nmbd", sizelimit=self.limit)
+        self.add_copy_spec("/var/log/samba/log.winbindd", sizelimit=self.limit)
+        self.add_copy_spec("/var/log/samba/log.winbindd-idmap",
+                           sizelimit=self.limit)
+        self.add_copy_spec("/var/log/samba/log.winbindd-dc-connect",
+                           sizelimit=self.limit)
+        self.add_copy_spec("/var/log/samba/log.wb-*", sizelimit=self.limit)
+
+        if self.get_option("all_logs"):
+            self.add_copy_spec("/var/log/samba/", sizelimit=self.limit)
+
         self.add_cmd_output([
             "wbinfo --domain='.' -g",
             "wbinfo --domain='.' -u",
-            "testparm -s -v"
+            "testparm -s",
         ])
 
 
@@ -42,4 +55,4 @@ class RedHatSamba(Samba, RedHatPlugin):
         super(RedHatSamba, self).setup()
         self.add_copy_spec("/etc/sysconfig/samba")
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
