@@ -8,9 +8,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin
 
@@ -21,6 +21,7 @@ class Satellite(Plugin, RedHatPlugin):
 
     plugin_name = 'satellite'
     profiles = ('sysmgmt',)
+    verify_packages = ('spacewalk.*',)
     satellite = False
     proxy = False
 
@@ -77,9 +78,7 @@ class Satellite(Plugin, RedHatPlugin):
         if self.satellite:
             self.add_copy_spec([
                 "/etc/tnsnames.ora",
-                "/etc/jabberd",
-                "/etc/tomcat6/",
-                "/var/log/tomcat6/"
+                "/etc/jabberd"
             ])
             self.add_cmd_output(
                 "spacewalk-debug --dir %s"
@@ -88,4 +87,4 @@ class Satellite(Plugin, RedHatPlugin):
         if self.proxy:
             self.add_copy_spec(["/etc/squid", "/var/log/squid"])
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
