@@ -8,9 +8,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin
 
@@ -28,7 +28,6 @@ class SELinux(Plugin, RedHatPlugin):
     packages = ('libselinux',)
 
     def setup(self):
-        # sestatus is always collected in check_enabled()
         self.add_copy_spec("/etc/selinux")
         self.add_cmd_output([
             "sestatus -b",
@@ -36,10 +35,11 @@ class SELinux(Plugin, RedHatPlugin):
             "selinuxdefcon root",
             "selinuxconlist root",
             "selinuxexeccon /bin/passwd",
-            "semanage -o -"
+            "semanage -o -",
+            "ps axuZww"
         ])
         if self.get_option('fixfiles'):
-            self.add_cmd_output("fixfiles -v check")
+            self.add_cmd_output("restorecon -Rvn /", stderr=False)
         if self.get_option('list'):
             self.add_cmd_output([
                 "semanage fcontext -l",
@@ -49,4 +49,4 @@ class SELinux(Plugin, RedHatPlugin):
             ])
 
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
