@@ -10,9 +10,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin
 
@@ -33,9 +33,9 @@ class Smartcard(Plugin, RedHatPlugin):
             "/etc/reader.conf.d/",
             "/etc/pam_pkcs11/"])
         self.add_cmd_output([
-            "pkcs11_inspect debug",
             "pklogin_finder debug",
             "ls -nl /usr/lib*/pam_pkcs11/"
         ])
+        self.add_forbidden_path("/etc/pam_pkcs11/nssdb/key[3-4].db")
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
