@@ -8,9 +8,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 
@@ -21,6 +21,7 @@ class System(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
 
     plugin_name = "system"
     profiles = ('system', 'kernel')
+    verify_packages = ('glibc', 'initscripts', 'zlib')
 
     def setup(self):
         self.add_copy_spec("/proc/sys")
@@ -30,4 +31,4 @@ class System(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
             "/proc/sys/net/ipv6/neigh/*/base_reachable_time")
 
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
