@@ -10,9 +10,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin
 
@@ -30,10 +30,14 @@ class Tuned(Plugin, RedHatPlugin):
             "tuned-adm active",
             "tuned-adm recommend"
         ])
+        self.add_copy_spec([
+            "/etc/tuned.conf",
+            "/etc/tune-profiles"
+        ])
         self.add_copy_spec([
             "/etc/tuned",
             "/usr/lib/tuned",
             "/var/log/tuned/tuned.log"
         ])
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
