@@ -8,9 +8,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from sos.plugins import Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin
 
@@ -32,5 +32,8 @@ class X11(Plugin, RedHatPlugin, DebianPlugin, UbuntuPlugin):
         ])
         self.add_forbidden_path("/etc/X11/X")
         self.add_forbidden_path("/etc/X11/fontpath.d")
+        self.add_cmd_output([
+            "xrandr --verbose"
+        ])
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
