@@ -10,11 +10,9 @@ from os import environ
 
 from sos.utilities import (ImporterHelper,
                            import_module,
-                           get_hash_name,
                            shell_out)
-from sos.plugins import IndependentPlugin
+from sos.plugins import IndependentPlugin, ExperimentalPlugin
 from sos import _sos as _
-import hashlib
 from textwrap import fill
 from six import print_
 from six.moves import input
@@ -28,7 +26,7 @@ def import_policy(name):
         return None
 
 
-def load(cache={}):
+def load(cache={}, sysroot=None):
     if 'policy' in cache:
         return cache.get('policy')
 
@@ -37,7 +35,7 @@ def load(cache={}):
     for module in helper.get_modules():
         for policy in import_policy(module):
             if policy.check():
-                cache['policy'] = policy()
+                cache['policy'] = policy(sysroot=sysroot)
 
     if 'policy' not in cache:
         cache['policy'] = GenericPolicy()
@@ -48,19 +46,29 @@ def load(cache={}):
 class PackageManager(object):
     """Encapsulates a package manager. If you provide a query_command to the
     constructor it should print each package on the system in the following
-    format:
-        package name|package.version\n
+    format::
+
+        package name|package.version
 
     You may also subclass this class and provide a get_pkg_list method to
     build the list of packages and versions.
     """
 
     query_command = None
+    verify_command = None
+    verify_filter = None
+    chroot = None
 
-    def __init__(self, query_command=None):
+    def __init__(self, chroot=None, query_command=None,
+                 verify_command=None, verify_filter=None):
         self.packages = {}
-        if query_command:
-            self.query_command = query_command
+
+        self.query_command = query_command if query_command else None
+        self.verify_command = verify_command if verify_command else None
+        self.verify_filter = verify_filter if verify_filter else None
+
+        if chroot:
+            self.chroot = chroot
 
     def all_pkgs_by_name(self, name):
         """
@@ -86,13 +94,19 @@ class PackageManager(object):
             return None
 
     def get_pkg_list(self):
-        """
-        returns a dictionary of packages in the following format:
-        {'package_name': {'name': 'package_name', '
-                          version': 'major.minor.version'}}
+        """Returns a dictionary of packages in the following
+        format::
+
+            {'package_name': {'name': 'package_name',
+                              'version': 'major.minor.version'}}
+
         """
         if self.query_command:
-            pkg_list = shell_out(self.query_command).splitlines()
+            cmd = self.query_command
+            pkg_list = shell_out(
+                cmd, timeout=0, chroot=self.chroot
+            ).splitlines()
+
             for pkg in pkg_list:
                 if '|' not in pkg:
                     continue
@@ -118,6 +132,43 @@ class PackageManager(object):
         name = "-".join(fields[:-3])
         return (name, version, release, arch)
 
+    def build_verify_command(self, packages):
+        """build_verify_command(self, packages) -> str
+            Generate a command to verify the list of packages given
+            in ``packages`` using the native package manager's
+            verification tool.
+
+            The command to be executed is returned as a string that
+            may be passed to a command execution routine (for e.g.
+            ``sos_get_command_output()``.
+
+            :param packages: a string, or a list of strings giving
+                             package names to be verified.
+            :returns: a string containing an executable command
+                      that will perform verification of the given
+                      packages.
+            :returntype: str or ``NoneType``
+        """
+        if not self.verify_command:
+            return None
+
+        by_regex = self.all_pkgs_by_name_regex
+        verify_list = map(by_regex, packages)
+
+        # No packages after regex match?
+        if not verify_list:
+            return None
+
+        verify_packages = ""
+        for package_list in verify_list:
+            for package in package_list:
+                if any([f in package for f in self.verify_filter]):
+                    continue
+                if len(verify_packages):
+                    verify_packages += " "
+                verify_packages += package
+        return self.verify_command + " " + verify_packages
+
 
 class Policy(object):
 
@@ -144,7 +195,10 @@ No changes will be made to system configuration.
     vendor_text = ""
     PATH = ""
 
-    def __init__(self):
+    _in_container = False
+    _host_sysroot = '/'
+
+    def __init__(self, sysroot=None):
         """Subclasses that choose to override this initializer should call
         super() to ensure that they get the required platform bits attached.
         super(SubClass, self).__init__(). Policies that require runtime
@@ -156,6 +210,7 @@ No changes will be made to system configuration.
         self.package_manager = PackageManager()
         self._valid_subclasses = []
         self.set_exec_path()
+        self._host_sysroot = sysroot
 
     def get_valid_subclasses(self):
         return [IndependentPlugin] + self._valid_subclasses
@@ -179,6 +234,14 @@ No changes will be made to system configuration.
         """
         return False
 
+    def in_container(self):
+        """ Returns True if sos is running inside a container environment.
+        """
+        return self._in_container
+
+    def host_sysroot(self):
+        return self._host_sysroot
+
     def dist_version(self):
         """
         Return the OS version
@@ -218,11 +281,13 @@ No changes will be made to system configuration.
                     return p
         return plugin_classes[0]
 
-    def validate_plugin(self, plugin_class):
+    def validate_plugin(self, plugin_class, experimental=False):
         """
         Verifies that the plugin_class should execute under this policy
         """
         valid_subclasses = [IndependentPlugin] + self.valid_subclasses
+        if experimental:
+            valid_subclasses += [ExperimentalPlugin]
         return any(issubclass(plugin_class, class_) for
                    class_ in valid_subclasses)
 
@@ -264,43 +329,29 @@ No changes will be made to system configuration.
         considered to be a superuser"""
         return (os.getuid() == 0)
 
-    def _create_checksum(self, final_filename=None):
-        if not final_filename:
-            return False
-
-        archive_fp = open(final_filename, 'rb')
-        digest = hashlib.new(get_hash_name())
-        digest.update(archive_fp.read())
-        archive_fp.close()
-        return digest.hexdigest()
-
-    def get_preferred_hash_algorithm(self):
+    def get_preferred_hash_name(self):
         """Returns the string name of the hashlib-supported checksum algorithm
         to use"""
         return "md5"
 
-    def display_results(self, final_filename=None, build=False):
+    def display_results(self, archive, directory, checksum):
+        # Display results is called from the tail of SoSReport.final_work()
+        #
+        # Logging is already shutdown and all terminal output must use the
+        # print() call.
 
         # make sure a report exists
-        if not final_filename:
+        if not archive and not directory:
             return False
 
         self._print()
 
-        if not build:
-            # store checksum into file
-            fp = open(final_filename + "." + get_hash_name(), "w")
-            checksum = self._create_checksum(final_filename)
-            if checksum:
-                fp.write(checksum + "\n")
-            fp.close()
-
+        if archive:
             self._print(_("Your sosreport has been generated and saved "
-                        "in:\n  %s") % final_filename)
+                        "in:\n  %s") % archive)
         else:
-            checksum = None
             self._print(_("sosreport build tree is located at : %s" %
-                        final_filename))
+                        directory))
 
         self._print()
         if checksum:
@@ -351,20 +402,28 @@ class LinuxPolicy(Policy):
     vendor = "None"
     PATH = "/bin:/sbin:/usr/bin:/usr/sbin"
 
-    def __init__(self):
-        super(LinuxPolicy, self).__init__()
+    _preferred_hash_name = None
+
+    def __init__(self, sysroot=None):
+        super(LinuxPolicy, self).__init__(sysroot=sysroot)
+
+    def get_preferred_hash_name(self):
+
+        if self._preferred_hash_name:
+            return self._preferred_hash_name
 
-    def get_preferred_hash_algorithm(self):
         checksum = "md5"
         try:
             fp = open("/proc/sys/crypto/fips_enabled", "r")
         except:
+            self._preferred_hash_name = checksum
             return checksum
 
         fips_enabled = fp.read()
         if fips_enabled.find("1") >= 0:
             checksum = "sha256"
         fp.close()
+        self._preferred_hash_name = checksum
         return checksum
 
     def default_runlevel(self):
@@ -401,30 +460,33 @@ class LinuxPolicy(Policy):
     def pre_work(self):
         # this method will be called before the gathering begins
 
-        localname = self.get_local_name()
+        cmdline_opts = self.commons['cmdlineopts']
+        customer_name = cmdline_opts.customer_name
+        localname = customer_name if customer_name else self.get_local_name()
+        caseid = cmdline_opts.case_id if cmdline_opts.case_id else ""
 
-        if not self.commons['cmdlineopts'].batch and not \
-                self.commons['cmdlineopts'].quiet:
+        if not cmdline_opts.batch and not \
+                cmdline_opts.quiet:
             try:
                 self.report_name = input(_("Please enter your first initial "
                                          "and last name [%s]: ") % localname)
 
                 self.case_id = input(_("Please enter the case id "
                                        "that you are generating this "
-                                       "report for: "))
+                                       "report for [%s]: ") % caseid)
                 self._print()
-            except:
+            except KeyboardInterrupt:
                 self._print()
-                self.report_name = localname
+                raise
 
         if len(self.report_name) == 0:
             self.report_name = localname
 
-        if self.commons['cmdlineopts'].customer_name:
-            self.report_name = self.commons['cmdlineopts'].customer_name
+        if customer_name:
+            self.report_name = customer_name
 
-        if self.commons['cmdlineopts'].case_id:
-            self.case_id = self.commons['cmdlineopts'].case_id
+        if cmdline_opts.case_id:
+            self.case_id = cmdline_opts.case_id
 
         self.report_name = self.sanitize_report_name(self.report_name)
         if self.case_id:
@@ -436,4 +498,4 @@ class LinuxPolicy(Policy):
         return
 
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
