@@ -11,21 +11,21 @@ class DebianPolicy(LinuxPolicy):
     report_name = ""
     ticket_number = ""
     package_manager = PackageManager(
-        "dpkg-query -W -f='${Package}|${Version}\\n' \*")
+        "dpkg-query -W -f='${Package}|${Version}\\n'")
     valid_subclasses = [DebianPlugin]
     PATH = "/usr/sbin:/usr/bin:/sbin:/bin:/usr/games:/usr/local/games" \
            + ":/usr/local/sbin:/usr/local/bin"
 
-    def __init__(self):
-        super(DebianPolicy, self).__init__()
+    def __init__(self, sysroot=None):
+        super(DebianPolicy, self).__init__(sysroot=sysroot)
         self.report_name = ""
         self.ticket_number = ""
         self.package_manager = PackageManager(
-            "dpkg-query -W -f='${Package}|${Version}\\n' \*")
+            "dpkg-query -W -f='${Package}|${Version}\\n'")
         self.valid_subclasses = [DebianPlugin]
 
     @classmethod
-    def check(self):
+    def check(cls):
         """This method checks to see if we are running on Debian.
            It returns True or False."""
         return os.path.isfile('/etc/debian_version')
@@ -42,4 +42,4 @@ class DebianPolicy(LinuxPolicy):
         except:
             return False
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
