@@ -10,11 +10,12 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 # This enables the use of with syntax in python 2.5 (e.g. jython)
+from __future__ import print_function
 import os
 import sys
 
@@ -36,18 +37,49 @@ class RedHatPolicy(LinuxPolicy):
     distro = "Red Hat"
     vendor = "Red Hat"
     vendor_url = "http://www.redhat.com/"
+    _redhat_release = '/etc/redhat-release'
     _tmp_dir = "/var/tmp"
+    _rpmq_cmd = 'rpm -qa --queryformat "%{NAME}|%{VERSION}\\n"'
+    _rpmv_cmd = 'rpm -V'
+    _rpmv_filter = ["debuginfo", "-devel"]
+    _in_container = False
+    _host_sysroot = '/'
 
-    def __init__(self):
-        super(RedHatPolicy, self).__init__()
+    def __init__(self, sysroot=None):
+        super(RedHatPolicy, self).__init__(sysroot=sysroot)
         self.report_name = ""
         self.ticket_number = ""
-        self.package_manager = PackageManager(
-            'rpm -qa --queryformat "%{NAME}|%{VERSION}\\n"')
+        # need to set _host_sysroot before PackageManager()
+        if sysroot:
+            self._container_init()
+            self._host_sysroot = sysroot
+        else:
+            sysroot = self._container_init()
+
+        self.package_manager = PackageManager(query_command=self._rpmq_cmd,
+                                              verify_command=self._rpmv_cmd,
+                                              verify_filter=self._rpmv_filter,
+                                              chroot=sysroot)
+
         self.valid_subclasses = [RedHatPlugin]
 
+        pkgs = self.package_manager.all_pkgs()
+
+        # If rpm query failed, exit
+        if not pkgs:
+            print("Could not obtain installed package list", file=sys.stderr)
+            sys.exit(1)
+
         # handle PATH for UsrMove
-        if self.package_manager.all_pkgs()['filesystem']['version'][0] == '3':
+        if 'filesystem' not in pkgs:
+            print("Could not find 'filesystem' package: "
+                  "assuming PATH settings")
+            usrmove = True
+        else:
+            filesys_version = pkgs['filesystem']['version']
+            usrmove = True if filesys_version[0] == '3' else False
+
+        if usrmove:
             self.PATH = "/usr/sbin:/usr/bin:/root/bin"
         else:
             self.PATH = "/sbin:/bin:/usr/sbin:/usr/bin:/root/bin"
@@ -56,12 +88,27 @@ class RedHatPolicy(LinuxPolicy):
         self.set_exec_path()
 
     @classmethod
-    def check(self):
+    def check(cls):
         """This method checks to see if we are running on Red Hat. It must be
         overriden by concrete subclasses to return True when running on a
         Fedora, RHEL or other Red Hat distribution or False otherwise."""
         return False
 
+    def _container_init(self):
+        """Check if sos is running in a container and perform container
+        specific initialisation based on ENV_HOST_SYSROOT.
+        """
+        if ENV_CONTAINER in os.environ:
+            if os.environ[ENV_CONTAINER] in ['docker', 'oci']:
+                self._in_container = True
+        if ENV_HOST_SYSROOT in os.environ:
+            self._host_sysroot = os.environ[ENV_HOST_SYSROOT]
+        use_sysroot = self._in_container and self._host_sysroot != '/'
+        if use_sysroot:
+            host_tmp_dir = os.path.abspath(self._host_sysroot + self._tmp_dir)
+            self._tmp_dir = host_tmp_dir
+        return self._host_sysroot if use_sysroot else None
+
     def runlevel_by_service(self, name):
         from subprocess import Popen, PIPE
         ret = []
@@ -92,6 +139,10 @@ class RedHatPolicy(LinuxPolicy):
     def get_local_name(self):
         return self.host_name()
 
+# Container environment variables on Red Hat systems.
+ENV_CONTAINER = 'container'
+ENV_HOST_SYSROOT = 'HOST'
+
 
 class RHELPolicy(RedHatPolicy):
     distro = "Red Hat Enterprise Linux"
@@ -118,15 +169,15 @@ No changes will be made to system configuration.
 %(vendor_text)s
 """)
 
-    def __init__(self):
-        super(RHELPolicy, self).__init__()
+    def __init__(self, sysroot=None):
+        super(RHELPolicy, self).__init__(sysroot=sysroot)
 
     @classmethod
-    def check(self):
+    def check(cls):
         """This method checks to see if we are running on RHEL. It returns True
         or False."""
-        return (os.path.isfile('/etc/redhat-release')
-                and not os.path.isfile('/etc/fedora-release'))
+        return (os.path.isfile(cls._redhat_release) and not
+                os.path.isfile('/etc/fedora-release'))
 
     def dist_version(self):
         try:
@@ -148,9 +199,9 @@ No changes will be made to system configuration.
     def rhn_username(self):
         try:
             # cfg = config.initUp2dateConfig()
-
-            return rpclib.xmlrpclib.loads(
+            rhn_username = rpclib.xmlrpclib.loads(
                 up2dateAuth.getSystemId())[0][0]['username']
+            return rhn_username.encode('utf-8', 'ignore')
         except:
             # ignore any exception and return an empty username
             return ""
@@ -159,17 +210,53 @@ No changes will be made to system configuration.
         return self.rhn_username() or self.host_name()
 
 
+class RedHatAtomicPolicy(RHELPolicy):
+    distro = "Red Hat Atomic Host"
+    msg = _("""\
+This command will collect diagnostic and configuration \
+information from this %(distro)s system.
+
+An archive containing the collected information will be \
+generated in %(tmpdir)s and may be provided to a %(vendor)s \
+support representative.
+
+Any information provided to %(vendor)s will be treated in \
+accordance with the published support policies at:\n
+  %(vendor_url)s
+
+The generated archive may contain data considered sensitive \
+and its content should be reviewed by the originating \
+organization before being passed to any third party.
+%(vendor_text)s
+""")
+
+    @classmethod
+    def check(cls):
+        atomic = False
+        if ENV_HOST_SYSROOT not in os.environ:
+            return atomic
+        host_release = os.environ[ENV_HOST_SYSROOT] + cls._redhat_release
+        if not os.path.exists(host_release):
+            return False
+        try:
+            for line in open(host_release, "r").read().splitlines():
+                atomic |= 'Atomic' in line
+        except:
+            pass
+        return atomic
+
+
 class FedoraPolicy(RedHatPolicy):
 
     distro = "Fedora"
     vendor = "the Fedora Project"
     vendor_url = "https://fedoraproject.org/"
 
-    def __init__(self):
-        super(FedoraPolicy, self).__init__()
+    def __init__(self, sysroot=None):
+        super(FedoraPolicy, self).__init__(sysroot=sysroot)
 
     @classmethod
-    def check(self):
+    def check(cls):
         """This method checks to see if we are running on Fedora. It returns
         True or False."""
         return os.path.isfile('/etc/fedora-release')
@@ -180,4 +267,4 @@ class FedoraPolicy(RedHatPolicy):
         return int(pkg["version"])
 
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
