@@ -17,9 +17,9 @@ supplied for application-specific information
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 import sys
 import traceback
@@ -83,7 +83,8 @@ class TempFileUtil(object):
 
     def new(self):
         fd, fname = tempfile.mkstemp(dir=self.tmp_dir)
-        fobj = open(fname, 'w')
+        # avoid TOCTOU race by using os.fdopen()
+        fobj = os.fdopen(fd, 'w+')
         self.files.append((fname, fobj))
         return fobj
 
@@ -111,8 +112,8 @@ class OptionParserExtended(OptionParser):
         print_()
         print_("Some examples:")
         print_()
-        print_(" enable cluster plugin only and collect dlm lockdumps:")
-        print_("   # sosreport -o cluster -k cluster.lockdump")
+        print_(" enable dlm plugin only and collect dlm lockdumps:")
+        print_("   # sosreport -o dlm -k dlm.lockdump")
         print_()
         print_(" disable memory and samba plugins, turn off rpm -Va "
                "collection:")
@@ -599,7 +600,8 @@ class SoSOptions(object):
                           default=deque())
         parser.add_option("--log-size", action="store",
                           dest="log_size", default=10, type="int",
-                          help="set a limit on the size of collected logs")
+                          help="set a limit on the size of collected logs "
+                               "(in MiB)")
         parser.add_option("-a", "--alloptions", action="store_true",
                           dest="usealloptions", default=False,
                           help="enable all options for loaded plugins")
@@ -682,6 +684,7 @@ class SoSReport(object):
         self._args = args
         self.sysroot = "/"
         self.sys_tmp = None
+        self.exit_process = False
 
         try:
             import signal
@@ -810,9 +813,16 @@ class SoSReport(object):
 
     def get_exit_handler(self):
         def exit_handler(signum, frame):
+            self.exit_process = True
             self._exit()
         return exit_handler
 
+    def handle_exception(self, plugname=None, func=None):
+        if self.raise_plugins or self.exit_process:
+            raise
+        if plugname and func:
+            self._log_plugin_exception(plugname, func)
+
     def _read_config(self):
         self.config = ConfigParser()
         if self.opts.config_file:
@@ -836,8 +846,7 @@ class SoSReport(object):
         self.soslog = logging.getLogger('sos')
         self.soslog.setLevel(logging.DEBUG)
         self.sos_log_file = self.get_temp_file()
-        self.sos_log_file.close()
-        flog = logging.FileHandler(self.sos_log_file.name)
+        flog = logging.StreamHandler(self.sos_log_file)
         flog.setFormatter(logging.Formatter(
             '%(asctime)s %(levelname)s: %(message)s'))
         flog.setLevel(logging.INFO)
@@ -860,8 +869,7 @@ class SoSReport(object):
         self.ui_log = logging.getLogger('sos_ui')
         self.ui_log.setLevel(logging.INFO)
         self.sos_ui_log_file = self.get_temp_file()
-        self.sos_ui_log_file.close()
-        ui_fhandler = logging.FileHandler(self.sos_ui_log_file.name)
+        ui_fhandler = logging.StreamHandler(self.sos_ui_log_file)
         ui_fhandler.setFormatter(logging.Formatter(
             '%(asctime)s %(levelname)s: %(message)s'))
 
@@ -873,18 +881,16 @@ class SoSReport(object):
             ui_console.setLevel(logging.INFO)
             self.ui_log.addHandler(ui_console)
 
-    def _finish_logging(self):
-        logging.shutdown()
-
+    def _add_sos_logs(self):
         # Make sure the log files are added before we remove the log
         # handlers. This prevents "No handlers could be found.." messages
         # from leaking to the console when running in --quiet mode when
         # Archive classes attempt to acess the log API.
         if getattr(self, "sos_log_file", None):
-            self.archive.add_file(self.sos_log_file.name,
+            self.archive.add_file(self.sos_log_file,
                                   dest=os.path.join('sos_logs', 'sos.log'))
         if getattr(self, "sos_ui_log_file", None):
-            self.archive.add_file(self.sos_ui_log_file.name,
+            self.archive.add_file(self.sos_ui_log_file,
                                   dest=os.path.join('sos_logs', 'ui.log'))
 
     def _get_disabled_plugins(self):
@@ -962,6 +968,7 @@ class SoSReport(object):
                     continue
 
                 plugin_class = self.policy.match_plugin(plugin_classes)
+
                 if not validate_plugin(plugin_class,
                                        experimental=self.opts.experimental):
                     self.soslog.warning(
@@ -1009,13 +1016,11 @@ class SoSReport(object):
                 for i in plugin_class.profiles:
                     if i in remaining_profiles:
                         remaining_profiles.remove(i)
-
                 self._load(plugin_class)
             except Exception as e:
                 self.soslog.warning(_("plugin %s does not install, "
                                       "skipping: %s") % (plug, e))
-                if self.raise_plugins:
-                    raise
+                self.handle_exception()
         if len(remaining_profiles) > 0:
             self.soslog.error(_("Unknown or inactive profile(s) provided:"
                                 " %s") % ", ".join(remaining_profiles))
@@ -1245,6 +1250,8 @@ class SoSReport(object):
             try:
                 plug.archive = self.archive
                 plug.setup()
+                if self.opts.verify:
+                    plug.setup_verify()
             except KeyboardInterrupt:
                 raise
             except (OSError, IOError) as e:
@@ -1254,13 +1261,9 @@ class SoSReport(object):
                                       % e.strerror)
                     self.ui_log.error("")
                     self._exit(1)
-                if self.raise_plugins:
-                    raise
-                self._log_plugin_exception(plugname, "setup")
+                self.handle_exception(plugname, "setup")
             except:
-                if self.raise_plugins:
-                    raise
-                self._log_plugin_exception(plugname, "setup")
+                self.handle_exception(plugname, "setup")
 
     def version(self):
         """Fetch version information from all plugins and store in the report
@@ -1268,8 +1271,10 @@ class SoSReport(object):
 
         versions = []
         versions.append("sosreport: %s" % __version__)
+
         for plugname, plug in self.loaded_plugins:
             versions.append("%s: %s" % (plugname, plug.version))
+
         self.archive.add_string(content="\n".join(versions),
                                 dest='version.txt')
 
@@ -1302,13 +1307,9 @@ class SoSReport(object):
                                       % e.strerror)
                     self.ui_log.error("")
                     self._exit(1)
-                if self.raise_plugins:
-                    raise
-                self._log_plugin_exception(plugname, "collect")
+                self.handle_exception(plugname, "collect")
             except:
-                if self.raise_plugins:
-                    raise
-                self._log_plugin_exception(plugname, "collect")
+                self.handle_exception(plugname, "collect")
         self.ui_log.info("")
 
     def report(self):
@@ -1359,8 +1360,8 @@ class SoSReport(object):
             output = PlainTextReport(report).unicode()
             fd.write(output)
             fd.flush()
-            self.archive.add_file(fd.name, dest=os.path.join('sos_reports',
-                                                             'sos.txt'))
+            self.archive.add_file(fd, dest=os.path.join('sos_reports',
+                                                        'sos.txt'))
         except (OSError, IOError) as e:
             if e.errno in fatal_fs_errors:
                 self.ui_log.error("")
@@ -1432,14 +1433,13 @@ class SoSReport(object):
             try:
                 html = plug.report()
             except:
-                if self.raise_plugins:
-                    raise
+                self.handle_exception()
             else:
                 rfd.write(html)
         rfd.write("</body></html>")
         rfd.flush()
-        self.archive.add_file(rfd.name, dest=os.path.join('sos_reports',
-                                                          'sos.html'))
+        self.archive.add_file(rfd, dest=os.path.join('sos_reports',
+                                                     'sos.html'))
 
     def postproc(self):
         for plugname, plug in self.loaded_plugins:
@@ -1452,13 +1452,9 @@ class SoSReport(object):
                                       % e.strerror)
                     self.ui_log.error("")
                     self._exit(1)
-                if self.raise_plugins:
-                    raise
-                self._log_plugin_exception(plugname, "postproc")
+                self.handle_exception(plugname, "postproc")
             except:
-                if self.raise_plugins:
-                    raise
-                self._log_plugin_exception(plugname, "postproc")
+                self.handle_exception(plugname, "postproc")
 
     def _create_checksum(self, archive, hash_name):
         if not archive:
@@ -1482,7 +1478,7 @@ class SoSReport(object):
         # files are closed and cleaned up at exit.
         #
         # All subsequent terminal output must use print().
-        self._finish_logging()
+        self._add_sos_logs()
 
         archive = None    # archive path
         directory = None  # report directory path (--build)
@@ -1565,6 +1561,7 @@ class SoSReport(object):
         self.policy.display_results(archive, directory, checksum)
 
         # clean up
+        logging.shutdown()
         if self.tempfile_util:
             self.tempfile_util.clean()
         if self.tmpdir:
