@@ -8,9 +8,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 from __future__ import with_statement
 
@@ -18,12 +18,11 @@ import os
 import re
 import inspect
 from subprocess import Popen, PIPE, STDOUT
-import zipfile
-import hashlib
 import logging
 import fnmatch
 import errno
 import shlex
+import glob
 
 from contextlib import closing
 
@@ -53,18 +52,6 @@ def fileobj(path_or_file, mode='r'):
         return closing(path_or_file)
 
 
-def get_hash_name():
-    """Returns the algorithm used when computing a hash"""
-    import sos.policies
-    policy = sos.policies.load()
-    try:
-        name = policy.get_preferred_hash_algorithm()
-        hashlib.new(name)
-        return name
-    except:
-        return 'sha256'
-
-
 def convert_bytes(bytes_, K=1 << 10, M=1 << 20, G=1 << 30, T=1 << 40):
     """Converts a number of bytes to a shorter, more human friendly format"""
     fn = float(bytes_)
@@ -81,10 +68,11 @@ def convert_bytes(bytes_, K=1 << 10, M=1 << 20, G=1 << 30, T=1 << 40):
 
 
 def find(file_pattern, top_dir, max_depth=None, path_pattern=None):
-    """generator function to find files recursively. Usage:
+    """Generator function to find files recursively.
+    Usage::
 
-    for filename in find("*.properties", "/var/log/foobar"):
-        print filename
+        for filename in find("*.properties", "/var/log/foobar"):
+            print filename
     """
     if max_depth:
         base_depth = os.path.dirname(top_dir).count(os.path.sep)
@@ -121,45 +109,63 @@ def is_executable(command):
     return any(os.access(path, os.X_OK) for path in candidates)
 
 
-def sos_get_command_output(command, timeout=300, runat=None):
-    """Execute a command through the system shell. First checks to see if the
-    requested command is executable. Returns (returncode, stdout, 0)"""
-    def _child_chdir():
-        if(runat):
-            try:
-                os.chdir(runat)
-            except:
-                self.log_error("failed to chdir to '%s'" % runat)
+def sos_get_command_output(command, timeout=300, stderr=False,
+                           chroot=None, chdir=None, env=None):
+    """Execute a command and return a dictionary of status and output,
+    optionally changing root or current working directory before
+    executing command.
+    """
+    # Change root or cwd for child only. Exceptions in the prexec_fn
+    # closure are caught in the parent (chroot and chdir are bound from
+    # the enclosing scope).
+    def _child_prep_fn():
+        if (chroot):
+                os.chroot(chroot)
+        if (chdir):
+                os.chdir(chdir)
 
     cmd_env = os.environ
     # ensure consistent locale for collected command output
     cmd_env['LC_ALL'] = 'C'
+    # optionally add an environment change for the command
+    if env:
+        for key, value in env.items():
+            cmd_env[key] = value
     # use /usr/bin/timeout to implement a timeout
     if timeout and is_executable("timeout"):
         command = "timeout %ds %s" % (timeout, command)
 
     # shlex.split() reacts badly to unicode on older python runtimes.
-    if six.PY2:
-        command = command.encode('utf-8')
+    if not six.PY3:
+        command = command.encode('utf-8', 'ignore')
     args = shlex.split(command)
+    # Expand arguments that are wildcard paths.
+    expanded_args = []
+    for arg in args:
+        expanded_arg = glob.glob(arg)
+        if expanded_arg:
+            expanded_args.extend(expanded_arg)
+        else:
+            expanded_args.append(arg)
     try:
-        p = Popen(args, shell=False, stdout=PIPE, stderr=STDOUT,
+        p = Popen(expanded_args, shell=False, stdout=PIPE,
+                  stderr=STDOUT if stderr else PIPE,
                   bufsize=-1, env=cmd_env, close_fds=True,
-                  preexec_fn=_child_chdir)
+                  preexec_fn=_child_prep_fn)
+        stdout, stderr = p.communicate()
     except OSError as e:
         if e.errno == errno.ENOENT:
             return {'status': 127, 'output': ""}
         else:
             raise e
 
-    stdout, stderr = p.communicate()
-
-    # Required hack while we still pass shell=True to Popen; a Popen
-    # call with shell=False for a non-existant binary will raise OSError.
     if p.returncode == 126 or p.returncode == 127:
         stdout = six.binary_type(b"")
 
-    return {'status': p.returncode, 'output': stdout.decode('utf-8')}
+    return {
+        'status': p.returncode,
+        'output': stdout.decode('utf-8', 'ignore')
+    }
 
 
 def import_module(module_fqname, superclasses=None):
@@ -178,18 +184,19 @@ def import_module(module_fqname, superclasses=None):
     return modules
 
 
-def shell_out(cmd, runat=None):
+def shell_out(cmd, timeout=30, chroot=None, runat=None):
     """Shell out to an external command and return the output or the empty
     string in case of error.
     """
-    return sos_get_command_output(cmd, runat=runat)['output']
+    return sos_get_command_output(cmd, timeout=timeout,
+                                  chroot=chroot, chdir=runat)['output']
 
 
 class ImporterHelper(object):
     """Provides a list of modules that can be imported in a package.
     Importable modules are located along the module __path__ list and modules
-    are files that end in .py. This class will read from PKZip archives as well
-    for listing out jar and egg contents."""
+    are files that end in .py.
+    """
 
     def __init__(self, package):
         """package is a package module
@@ -206,8 +213,7 @@ class ImporterHelper(object):
     def _get_plugins_from_list(self, list_):
         plugins = [self._plugin_name(plugin)
                    for plugin in list_
-                   if "__init__" not in plugin
-                   and plugin.endswith(".py")]
+                   if "__init__" not in plugin and plugin.endswith(".py")]
         plugins.sort()
         return plugins
 
@@ -220,38 +226,6 @@ class ImporterHelper(object):
             else:
                 return []
 
-    def _get_path_to_zip(self, path, tail_list=None):
-        if not tail_list:
-            tail_list = ['']
-
-        if path.endswith(('.jar', '.zip', '.egg')):
-            return path, os.path.join(*tail_list)
-
-        head, tail = os.path.split(path)
-        tail_list.insert(0, tail)
-
-        if head == path:
-            raise Exception("not a zip file")
-        else:
-            return self._get_path_to_zip(head, tail_list)
-
-    def _find_plugins_in_zipfile(self, path):
-        try:
-            path_to_zip, tail = self._get_path_to_zip(path)
-            zf = zipfile.ZipFile(path_to_zip)
-            # the path will have os separators, but the zipfile will
-            # always have '/'
-            tail = tail.replace(os.path.sep, "/")
-            root_names = [name for name in zf.namelist() if tail in name]
-            candidates = self._get_plugins_from_list(root_names)
-            zf.close()
-            if candidates:
-                return candidates
-            else:
-                return []
-        except (IOError, Exception):
-            return []
-
     def get_modules(self):
         """Returns the list of importable modules in the configured python
         package. """
@@ -259,9 +233,7 @@ class ImporterHelper(object):
         for path in self.package.__path__:
             if os.path.isdir(path) or path == '':
                 plugins.extend(self._find_plugins_in_dir(path))
-            else:
-                plugins.extend(self._find_plugins_in_zipfile(path))
 
         return plugins
 
-# vim: et ts=4 sw=4
+# vim: set et ts=4 sw=4 :
